@@ -37,6 +37,8 @@ _map_pyconv2camelcase = {'prior_model' : 'PriorModel',
                          'positivity' : 'Positivity',
                          'weight_type' : 'weightType',
                          'geometry' : 'Geometry',
+                         'dist_source_detector' : 'DistSourceDetector',
+                         'magnification' : 'Magnification',
                          'num_channels' : 'NChannels',
                          'num_views' : 'NViews',
                          'num_slices' : 'NSlices',
@@ -158,10 +160,12 @@ def _cmd_exec(exec_path = __exec_path__, *args, **kwargs):
 ##################################################################
 
 def _init_geometry( angles, num_channels, num_views, num_slices, num_rows, num_cols,
+                    geometry, dist_source_detector, magnification,
                     delta_channel, delta_pixel, roi_radius, center_offset, verbose,
                     svmbir_lib_path = __svmbir_lib_path, object_name = 'object'):
 
     sinoparams, imgparams, settings = utils.get_params_dicts(angles, num_channels, num_views, num_slices, num_rows, num_cols,
+                    geometry, dist_source_detector, magnification,
                     delta_channel, delta_pixel, roi_radius, center_offset, verbose,
                     svmbir_lib_path, object_name, interface='Command Line')
 
@@ -176,6 +180,7 @@ def _init_geometry( angles, num_channels, num_views, num_slices, num_rows, num_c
 
 
 def multires_recon(sino, angles, weights, weight_type, init_image, prox_image, init_proj,
+                   geometry, dist_source_detector, magnification,
                    num_rows, num_cols, roi_radius, delta_channel, delta_pixel, center_offset,
                    sigma_y, snr_db, sigma_x, p, q, T, b_interslice,
                    sharpness, positivity, max_resolutions, stop_threshold, max_iterations,
@@ -216,6 +221,7 @@ def multires_recon(sino, angles, weights, weight_type, init_image, prox_image, i
             print(f'Calling multires_recon for axial size (rows,cols)=({lr_num_rows},{lr_num_cols}).')
 
         lr_recon = multires_recon(sino=sino, angles=angles, weights=weights, weight_type=weight_type,
+                        geometry=geometry, dist_source_detector=dist_source_detector, magnification=magnification,
                         init_image=lr_init_image, prox_image=lr_prox_image, init_proj=init_proj,
                         num_rows=lr_num_rows, num_cols=lr_num_cols, roi_radius=roi_radius,
                         delta_channel=delta_channel, delta_pixel=lr_delta_pixel, center_offset=center_offset,
@@ -245,6 +251,8 @@ def multires_recon(sino, angles, weights, weight_type, init_image, prox_image, i
                             stop_threshold, max_iterations,init_image_value=init_image_value, interface = 'Command Line')
 
     paths, sinoparams, imgparams = _init_geometry(angles, center_offset=center_offset,
+                                                  geometry=geometry, dist_source_detector=dist_source_detector,
+                                                  magnification=magnification,
                                                   num_channels=num_channels, num_views=num_views, num_slices=num_slices,
                                                   num_rows=num_rows, num_cols=num_cols,
                                                   delta_channel=delta_channel, delta_pixel=delta_pixel,
